/*
 * Copyright (C) 2008 Luke Kenneth Casson Leighton <lkcl@lkcl.net>
 * Copyright (C) 2008 Alp Toker <alp@atoker.com>
 * Copyright (C) 2008 Apple Inc.
 */

#include "config.h"

#include <wtf/GetPtr.h>
#include "CSSRule.h"
#include "CSSValue.h"
#include "CanvasPixelArray.h"
#include "DOMWindow.h"
#include "Element.h"
#include "Event.h"
#include "GDOMBinding.h"
#include "GDOMObject.h"
#include "HTMLCollection.h"
#include "HTMLModElement.h"
#include "Node.h"
#include "StyleSheet.h"
#include "Text.h"
#include "gdom/GStringConvert.h"
#include "gdom/GdomHTMLElement.h"
#include "gdom/GdomHTMLModElement.h"
#include "gdom/PrivateGdomDOMObject.h"
#include "gdom/PrivateGdomHTMLElement.h"
#include "gdom/PrivateGdomHTMLModElement.h"
#include "gdom/PrivateIntGdomHTMLModElement.h"

namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore

namespace WebCore {
} /* namespace WebCore */
extern "C" {

GDOMHTMLModElement::GDOMHTMLModElement(PassRefPtr<WebCore::HTMLModElement> impl)
    : GDOMHTMLElement(impl)
{
}

} /* extern "C" */


#include "config.h"
#include "glib-object.h"
#include <webkit/webkitdefines.h>
#include <webkit/webkitprivate.h> 
#include "DOMWindow.h" /* yukk: TODO - make this optional */
#include "Node.h" /* yukk: TODO - make this optional */
#include "NamedNodeMap.h" /* yukk: TODO - make this optional */
#include "CanvasPattern.h" /* yukk: TODO - make this optional */
#include "CanvasGradient.h" /* yukk: TODO - make this optional */
#include "CanvasStyle.h" /* yukk: TODO - make this optional */
#include "CanvasRenderingContext2D.h" /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomDOMObject.h> /* yukk: TODO - make this optional */
#include <gdom/GdomEventTargetNode.h> /* yukk: TODO - make this optional */
#include <gdom/PrivateGdomEventTargetNode.h> /* yukk: TODO - make this optional on EventTarget*/
#include "HTMLModElement.h"
#include <gdom/GdomHTMLModElement.h>
#include <gdom/PrivateGdomHTMLModElement.h>
#include <gdom/PrivateIntGdomHTMLModElement.h>
#include <gdom/GdomHTMLModElementprops.h>

#include "gdom/GStringConvert.h"

#include "CanvasPixelArray.h"
#include "Event.h"
#include "Text.h"
#include "CSSValue.h"
#include "CSSRule.h"
#include "HTMLCollection.h"
#include "StyleSheet.h"
#include "Document.h"
#include "webkitmarshal.h"
#include <gdom/GdomEvent.h>



namespace WebCore {
    gpointer toGDOM(Node* node);
    gpointer toGDOM(CSSValue* node);
    gpointer toGDOM(CSSRule* node);
    gpointer toGDOM(Element* node);
    gpointer toGDOM(Document* node);
    gpointer toGDOM(HTMLCollection* node);
    //gpointer toGDOM(SVGPathSeg* node);
    gpointer toGDOM(StyleSheet* node);
    gpointer toGDOM(EventTargetNode* node);
    gpointer toGDOM(EventTarget* node);
    gpointer toGDOM(Event* node);
    gpointer toGDOM(CanvasPixelArray* node);
    gpointer toGDOM(DOMWindow* node);
    gpointer toGDOM(Text* node);
} // namespace WebCore



G_BEGIN_DECLS

G_DEFINE_TYPE(GdomHTMLModElement, gdom_html_mod_element, GDOM_TYPE_HTML_ELEMENT);

/*
struct _GdomHTMLModElementPrivate {
    class WebCore::HTMLModElement *item;
};

#define GDOM_HTML_MOD_ELEMENT_GET_PRIVATE(obj) (G_TYPE_INSTANCE_GET_PRIVATE((obj), GDOM_TYPE_HTML_MOD_ELEMENT, GdomHTMLModElementPrivate))
*/
G_END_DECLS
WebCore::HTMLModElement *
gdom_html_mod_element_get_private(GdomHTMLModElement *request)
{
    GDOMHTMLModElement *res;
    res = static_cast<GDOMHTMLModElement*>(gdom_dom_object_get_private(GDOM_DOM_OBJECT(request)));
    return static_cast<WebCore::HTMLModElement*>(res->impl());
}

G_BEGIN_DECLS

enum {
    BROWSER_EVENT,
    LAST_SIGNAL
};

static guint event_signals[LAST_SIGNAL] = { 0, };

enum {
    PROP_0,
    PROP_CITE,
    PROP_DATE_TIME,
};


static void gdom_html_mod_element_finalize(GObject* object)
{
    /*GdomHTMLModElement* request = GDOM_HTML_MOD_ELEMENT(object);*/
    /*GdomHTMLModElementPrivate* priv = request->priv;*/

    /*GObjectClass *parent_class = g_type_class_peek (g_type_peek_parent (GDOM_TYPE_HTML_ELEMENT));*/

    /* Free any memory or close any files */

    /*parent_class-> finalize (object);*/

    G_OBJECT_CLASS(gdom_html_mod_element_parent_class)->finalize(object);
}

static void gdom_html_mod_element__set_property_fn(GObject * object, guint prop_id,
                     const GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLModElement *self = GDOM_HTML_MOD_ELEMENT(object);
    WebCore::HTMLModElement * gself = (gdom_html_mod_element_get_private(self));
    switch (prop_id) {
     case PROP_CITE:
    {
         gself->setCite(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
     case PROP_DATE_TIME:
    {
         gself->setDateTime(WebCore::String::fromUTF8(g_value_get_string (value)) );
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_mod_element__get_property_fn(GObject * object, guint prop_id,
                     GValue * value,
                     GParamSpec * pspec)
{
    GdomHTMLModElement *self = GDOM_HTML_MOD_ELEMENT(object);
    WebCore::HTMLModElement * gself = (gdom_html_mod_element_get_private(self));
    switch (prop_id) {
    case PROP_CITE:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->cite()));
         break;
    }
    case PROP_DATE_TIME:
    {
         g_value_set_string (value, _G_GET_UTF8(gself->dateTime()));
         break;
    }
    default:
        G_OBJECT_WARN_INVALID_PROPERTY_ID(object, prop_id, pspec);
        break;
    }
}


static void gdom_html_mod_element_class_init(GdomHTMLModElementClass* requestClass)
{
    GObjectClass *g_klass = G_OBJECT_CLASS (requestClass);
    g_klass->finalize = gdom_html_mod_element_finalize;
    g_klass->set_property = gdom_html_mod_element__set_property_fn;
    g_klass->get_property = gdom_html_mod_element__get_property_fn;

    g_object_class_install_property (g_klass, PROP_CITE,
            g_param_spec_string ("cite", /* name */
                "html_mod_element_cite", /* short description */
                "read-write  gchar * HTMLModElement.cite", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));

     g_object_class_install_property (g_klass, PROP_DATE_TIME,
            g_param_spec_string ("date_time", /* name */
                "html_mod_element_date_time", /* short description */
                "read-write  gchar * HTMLModElement.date_time", /* longer - could do with some extra doc stuff here */
                 "", /* default */
                 (GParamFlags)G_PARAM_READWRITE));





    /*g_type_class_remove_private(requestClass, sizeof(GdomHTMLModElementPrivate));*/
}

static void gdom_html_mod_element_init(GdomHTMLModElement* request)
{
    /*GdomHTMLModElementPrivate* priv = GDOM_HTML_MOD_ELEMENT_GET_PRIVATE(request);
    request->priv = priv;*/
}

} /* extern "C" */

